============
Applications
============


zfitpy
======

This Python package fits electrical models to measured impedance data.  The model is specified using Lcapy network syntax, e.g., "R('R1') + L('L1') | R('R2')".  The electrical components include constant phase elements (CPE).

zfitpy can be installed using pip:

.. code-block:: console

    $ pip3 install zfitpy

The source code is available from `https://github.com/mph-/zfitpy <https://github.com/mph-/zfitpy>`_.
